@@ -35,7 +35,7 @@ Chart::OFC2::Bar - OFC2 bar chart
 
 =begin html
 
-<div><img src="http://github.com/jozef/chart-ofc2/raw/master/examples/screenshots/bar-chart-test.png" width="600" height="400" alt="Bar chart test" title="click link below to see the interactive chart" /></div>
+<div><img src="http://github.com/jozef/chart-ofc2/raw/master/examples/screenshots/bar-chart.png" width="600" height="400" alt="Bar chart test" title="click link below to see the interactive chart" /></div>
 <ul>
 <li><a href="http://cpansearch.perl.org/src/JKUTEJ/Chart-OFC2-0.08_01/examples/for-pod/bar.html">interactive version</a></li>
 <li><a href="http://cpansearch.perl.org/src/JKUTEJ/Chart-OFC2-0.08_01/examples/for-pod/bar-data.json">json source</a></li>
@@ -48,7 +48,7 @@ Chart::OFC2::Bar - OFC2 bar chart
 use Moose;
 use MooseX::StrictConstructor;
 
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 
 extends 'Chart::OFC2::BarLineBase';
 
@@ -73,7 +73,7 @@ has '+type_name' => (default => 'bar');
 package Chart::OFC2::Bar::3D;
 use Moose;
 use MooseX::StrictConstructor;
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 extends 'Chart::OFC2::Bar';
 
 =head1 PROPERTIES
@@ -98,7 +98,7 @@ Fade bar chart
 package Chart::OFC2::Bar::Fade;
 use Moose;
 use MooseX::StrictConstructor;
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 extends 'Chart::OFC2::Bar';
 
 =head1 PROPERTIES
@@ -123,7 +123,7 @@ Glass bar chart
 package Chart::OFC2::Bar::Glass;
 use Moose;
 use MooseX::StrictConstructor;
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 extends 'Chart::OFC2::Bar';
 
 =head1 PROPERTIES
@@ -148,7 +148,7 @@ Sketch bar chart
 package Chart::OFC2::Bar::Sketch;
 use Moose;
 use MooseX::StrictConstructor;
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 extends 'Chart::OFC2::Bar';
 
 =head1 PROPERTIES
@@ -173,7 +173,7 @@ Filled bar chart
 package Chart::OFC2::Bar::Filled;
 use Moose;
 use MooseX::StrictConstructor;
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 extends 'Chart::OFC2::Bar';
 
 =head1 PROPERTIES
@@ -201,7 +201,7 @@ Stack bar chart
 package Chart::OFC2::Bar::Stack;
 use Moose;
 use MooseX::StrictConstructor;
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 extends 'Chart::OFC2::Bar';
 
 =head1 PROPERTIES
