@@ -28,12 +28,16 @@ use Moose;
 use Moose::Util::TypeConstraints;
 use MooseX::StrictConstructor;
 
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 
 coerce 'Chart::OFC2::Title'
     => from 'Str'
     => via { Chart::OFC2::Title->new('text' => $_) };
 
+coerce 'Chart::OFC2::Title'
+    => from 'HashRef'
+    => via { Chart::OFC2::Title->new( $_ ) };
+
 =head1 PROPERTIES
 
     has 'text'  => (is => 'rw', isa => 'Str', );
